Rename library and update build system
Change-Id: I78c6a412c5e2181e58649c0e0aa2aa2f97da16a1
diff --git a/src/group-manager-db.hpp b/src/group-manager-db.hpp
index a311ecf..59c0e66 100644
--- a/src/group-manager-db.hpp
+++ b/src/group-manager-db.hpp
@@ -2,19 +2,19 @@
/**
* Copyright (c) 2014-2018, Regents of the University of California
*
* This file is part of ndn-group-encrypt (Group-based Encryption Protocol for NDN).
* See AUTHORS.md for complete list of ndn-group-encrypt authors and contributors.
*
* ndn-group-encrypt is free software: you can redistribute it and/or modify it under the terms
* of the GNU General Public License as published by the Free Software Foundation,
* either version 3 of the License, or (at your option) any later version.
*
- * ndn-group-encrypt is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+ * NAC is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
* without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
* PURPOSE. See the GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License along with
- * ndn-group-encrypt, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
+ * NAC, e.g., in COPYING.md file. If not, see <http://www.gnu.org/licenses/>.
*
* @author Zhiyi Zhang <zhiyi@cs.ucla.edu>
*/
@@ -25,7 +25,7 @@
#include "schedule.hpp"
namespace ndn {
-namespace gep {
+namespace nac {
/**
* @brief GroupManagerDB is a class to manage the database of group manager.
@@ -38,17 +38,15 @@
class Error : public std::runtime_error
{
public:
- explicit Error(const std::string& what)
- : std::runtime_error(what)
- {
- }
+ using std::runtime_error::runtime_error;
};
public:
/**
* @brief Create the database of group manager at path @p dbPath.
*/
- explicit GroupManagerDB(const std::string& dbPath);
+ explicit
+ GroupManagerDB(const std::string& dbPath);
~GroupManagerDB();
@@ -202,7 +200,7 @@
unique_ptr<Impl> m_impl;
};
-} // namespace gep
+} // namespace nac
} // namespace ndn
#endif // GEP_GROUP_MANAGER_DB_HPP
@@ -2,19 +2,19 @@
* Copyright (c) 2014-2018, Regents of the University of California
*
- * This file is part of ndn-group-encrypt (Group-based Encryption Protocol for NDN).
- * See AUTHORS.md for complete list of ndn-group-encrypt authors and contributors.
+ * This file is part of NAC (Name-Based Access Control for NDN).
+ * See AUTHORS.md for complete list of NAC authors and contributors.
*
@@ -2,19 +2,19 @@
*
- * ndn-group-encrypt is free software: you can redistribute it and/or modify it under the terms
+ * NAC is free software: you can redistribute it and/or modify it under the terms
* of the GNU General Public License as published by the Free Software Foundation,
* either version 3 of the License, or (at your option) any later version.